// create a private scope
(function(){
	// read the "keyword" assigned to this SCRIPT tag
	var self_script = document.getElementById("script_newFilterToggle");
	if( !self_script )
		return;
	var tag = self_script.getAttribute("data-keyword");
	if( !tag )
		return;
	tag = tag.toLowerCase();
	// remove this script's ID after reading its data,  so that other instances of this script can be placed and read
	self_script.removeAttribute("id");		// prevent it from being initialized again
	
	
	
	// access the corresponding HTML elements for this toggle
	var self_elm = document.getElementById("toggle_" + tag);
	if( !self_elm )
		return;
	
	
	
	var checkbox = self_elm.getElementsByTagName("input")[0];
	
	// Set the starting state based on localStorage
	var filters_str = localStorage.getItem("defaultSearch") || "";
	var filters_ary = filters_str.split(',');
	var filterValue = "-" + tag;
	for(var i=filters_ary.length; i>=0; i--){
		// if:  this button's keyword is in the filter list
		if( filters_ary[i] === filterValue ){
			// set this button to the "exclude" state
			checkbox.checked = true;
			break;
		}
	}// for each filter
	
	
	
	// program the checkbox
	checkbox.onchange = changeKeyword;
	checkbox.onkeypress = keyPress;
	
	
	
	// announce keyword toggle
	function changeKeyword(){
		var thisCheck = this;
		var eventName = "";
		
		if( thisCheck.checked === true )
			eventName = "filter:exclude";
		
		if( thisCheck.checked === false )
			eventName = "filter:include";
		
		var new_evt = new Event( eventName );
		new_evt.value = thisCheck.getAttribute("data-keyword");
		self_elm.dispatchEvent( new_evt );
		window.top.dispatchEvent( new_evt );
	}// change-keyword()
	
	
	
	// detect enter key
	function keyPress( evt ){
		if( evt.key === "Enter" )
			enterKey.apply( this );
	}// keyPress()
	
	
	
	// enter key  =>  toggle keyword
	function enterKey(){
		var thisCheck = this;
		var newValue = "include";
		
		// toggle logic
		// include => exclude
		if( thisCheck.checked === true )
			newValue = false;
		
		// exclude => include
		if( thisCheck.checked === false )
			newValue = true
		
		// apply the toggle
		thisCheck.checked = newValue;
		thisCheck.focus();
		
		changeKeyword.apply( thisCheck );
	}// enterKey()
	
	
	
	self_elm.addEventListener("filter:include", function( evt ){
		var keyword = evt.value;
		if( !keyword )
			return;
		
		removeFilter( keyword );
	} );// filter:include
	
	
	
	self_elm.addEventListener("filter:exclude", function( evt ){
		var keyword = evt.value;
		if( !keyword )
			return;
		
		addFilter( keyword );
	} );// filter:exclude
	
	
	
	function removeFilter( tag ){
		var filterValue = "-" + tag;
		// read current filters
		var filters_str = localStorage.getItem("defaultSearch") || "";
		var filters_ary = filters_str.split(',');
		if( filters_ary[0] === "" )
			filters_ary.splice( 0, 1 );
		
		// remove this filter from localStorage
		for(var i=filters_ary.length-1; i>=0; i--){		// for each: filter
			if( filters_ary[i] === filterValue )				// if this value is found
				filters_ary.splice( i, 1 );								// remove this value from the array
		}// for each: filter
		
		// update localStorage
		localStorage.setItem("defaultSearch", filters_ary);
	}// removeFilter()
	
	
	
	function addFilter( tag ){
		var filterValue = "-" + tag;
		// read current filters
		var filters_str = localStorage.getItem("defaultSearch") || "";
		var filters_ary = filters_str.split(',');
		if( filters_ary[0] === "" )
			filters_ary.splice( 0, 1 );
		
		// remove this filter from localStorage
		for(var i=filters_ary.length-1; i>=0; i--){		// for each: filter
			if( filters_ary[i] === filterValue )				// if this value is found
				filters_ary.splice( i, 1 );								// remove this value from the array
		}// for each: filter
		
		// add this filter to localStorage
		filters_ary.push( filterValue );
		
		// update localStorage
		localStorage.setItem("defaultSearch", filters_ary);
	}// addFilter()
	
	
	
})();// private scope